==> spring-rabbit-2.1.0.RELEASE-sources.jar: org/springframework/amqp/rabbit/listener/RabbitListenerContainerFactory.java <==
/*
 * Copyright 2002-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.amqp.rabbit.listener;

import org.springframework.amqp.core.MessageListener;
import org.springframework.lang.Nullable;

/**
 * Factory of {@link MessageListenerContainer}s.
 * @param <C> the container type.
 * @author Stephane Nicoll
 * @author Gary Russell
 * @since 1.4
 * @see RabbitListenerEndpoint
 */
@FunctionalInterface
public interface RabbitListenerContainerFactory<C extends MessageListenerContainer> {

	/**
	 * Create a {@link MessageListenerContainer} for the given
	 * {@link RabbitListenerEndpoint}.
	 * @param endpoint the endpoint to configure.
	 * @return the created container.
	 */
	C createListenerContainer(@Nullable RabbitListenerEndpoint endpoint);

	/**
	 * Create a {@link MessageListenerContainer} with no {@link MessageListener}
	 * or queues; the listener must be added later before the container is started.
	 * @return the created container.
	 * @since 2.1.
	 */
	default C createListenerContainer() {
		return createListenerContainer(null);
	}

}

==> spring-rabbit-2.1.3.RELEASE-sources.jar: org/springframework/amqp/rabbit/listener/RabbitListenerContainerFactory.java <==
/*
 * Copyright 2002-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.amqp.rabbit.listener;

import org.springframework.lang.Nullable;

/**
 * Factory of {@link MessageListenerContainer}s.
 * @param <C> the container type.
 * @author Stephane Nicoll
 * @author Gary Russell
 * @since 1.4
 * @see RabbitListenerEndpoint
 */
@FunctionalInterface
public interface RabbitListenerContainerFactory<C extends MessageListenerContainer> {

	/**
	 * Create a {@link MessageListenerContainer} for the given
	 * {@link RabbitListenerEndpoint}.
	 * @param endpoint the endpoint to configure.
	 * @return the created container.
	 */
	C createListenerContainer(@Nullable RabbitListenerEndpoint endpoint);

	/**
	 * Create a {@link MessageListenerContainer} with no
	 * {@link org.springframework.amqp.core.MessageListener} or queues; the listener must
	 * be added later before the container is started.
	 * @return the created container.
	 * @since 2.1.
	 */
	default C createListenerContainer() {
		return createListenerContainer(null);
	}

}
